Two default namelists to use come from here: 
https://gitlab.dkrz.de/modular_esm/REcoM/-/tree/922b6b32113e7bf6144715eda64b7e9299e8c341

- `namelist.recom` for setup fesom-recom
- `namelist.recom_co2_coupling` for setup awicm_recom
